# -*- coding: utf-8 -*-
# @Author  : Gloo
# @time    : 2019/11/28 16:43
# @File    : view.py
# @Software: PyCharm
from .route import _Router
from functools import partial


class Mate(type):
    def __new__(cls, name, pts, attr):
        created = super().__new__(cls, name, pts, attr)
        route_name = attr.get("route_name", None)
        if not (route_name and isinstance(route_name, str)):
            route_name = name.lower()
        route_name = route_name if route_name.startswith('/') else '/'+route_name

        api = attr.get("api", None)

        if isinstance(api, _Router):
            for method in ('get', 'put', 'post', 'delete'):
                if method in attr:
                    api.route(route_name, method.upper())(partial(attr[method], created))

        return created


class View(metaclass=Mate):
    api = None
    route_name = None

    def get(self, *args, **kwargs):
        raise NotImplementedError("base view not implemented")

    def post(self, *args, **kwargs):
        raise NotImplementedError("base view not implemented")

    def put(self, *args, **kwargs):
        raise NotImplementedError("base view not implemented")

    def delete(self, *args, **kwargs):
        raise NotImplementedError("base view not implemented")



from setuptools import setup


with open("README.md", "r", encoding="utf8") as fh:
    long_description = fh.read()


# 导入setup函数并传参
setup(name='glooweb',
      version='0.1.7',
      keywords=("api", "web"),
      description='Simple web framework based on WSGI protocol',
      long_description=long_description,
      long_description_content_type="text/markdown",
      author='gloo',
      author_email='gloo.luo@foxmail.com',
      packages=['glooweb'],
      install_requires=[
          'Webob>=1.8.5'
      ],
      data_files=["./README.md"]
      )
